diff --git a/module/block/config.php b/module/block/config.php
index 56f6fe5c09..91d4a5b03c 100644
--- a/module/block/config.php
+++ b/module/block/config.php
@@ -15,20 +15,20 @@ $config->block->editor = new stdclass();
$config->block->editor->set = array('id' => 'html', 'tools' => 'simple');
$config->block->longBlock = array();
-$config->block->longBlock['']['flowchart'] = 'flowchart';
-$config->block->longBlock['']['welcome'] = 'welcome';
-$config->block->longBlock['product']['statistic'] = 'statistic';
-$config->block->longBlock['project']['statistic'] = 'statistic';
-$config->block->longBlock['qa']['statistic'] = 'statistic';
-$config->block->longBlock['program']['cmmireport'] = 'cmmireport';
-$config->block->longBlock['program']['cmmiissue'] = 'cmmiissue';
-$config->block->longBlock['program']['cmmirisk'] = 'cmmirisk';
+$config->block->longBlock['']['flowchart'] = 'flowchart';
+$config->block->longBlock['']['welcome'] = 'welcome';
+$config->block->longBlock['product']['statistic'] = 'statistic';
+$config->block->longBlock['project']['statistic'] = 'statistic';
+$config->block->longBlock['qa']['statistic'] = 'statistic';
+$config->block->longBlock['program']['waterfallreport'] = 'waterfallreport';
+$config->block->longBlock['program']['waterfallissue'] = 'waterfallissue';
+$config->block->longBlock['program']['waterfallrisk'] = 'waterfallrisk';
$config->block->shortBlock = array();
-$config->block->shortBlock['product']['overview'] = 'overview';
-$config->block->shortBlock['project']['overview'] = 'overview';
-$config->block->shortBlock['program']['cmmiestimate'] = 'cmmiestimate';
-$config->block->shortBlock['program']['cmmiprogress'] = 'cmmiprogress';
+$config->block->shortBlock['product']['overview'] = 'overview';
+$config->block->shortBlock['project']['overview'] = 'overview';
+$config->block->shortBlock['program']['waterfallestimate'] = 'waterfallestimate';
+$config->block->shortBlock['program']['waterfallprogress'] = 'waterfallprogress';
$config->block->shortBlock['']['contribute'] = 'contribute';
$config->statistic = new stdclass();
diff --git a/module/block/lang/de.php b/module/block/lang/de.php
index 7bd7dd812c..6cd12bab0b 100644
--- a/module/block/lang/de.php
+++ b/module/block/lang/de.php
@@ -50,7 +50,7 @@ $lang->block->openedStories = 'The Number Of Stories Created';
$lang->block->resolvedTasks = 'The Number Of Tasks Resolved';
$lang->block->resolvedBugs = 'The Number Of Bugs Resolved';
$lang->block->openedTestcases = 'The Number Of Test Case Created';
-$lang->block->cmmi = 'CMMI 3';
+$lang->block->waterfall = 'CMMI 3';
$lang->block->scrum = 'Scrum+';
$lang->block->params = new stdclass();
diff --git a/module/block/lang/en.php b/module/block/lang/en.php
index 5ce4f78493..4377c67713 100644
--- a/module/block/lang/en.php
+++ b/module/block/lang/en.php
@@ -52,7 +52,7 @@ $lang->block->openedStories = 'The Number Of Stories Created';
$lang->block->resolvedTasks = 'The Number Of Tasks Resolved';
$lang->block->resolvedBugs = 'The Number Of Bugs Resolved';
$lang->block->openedTestcases = 'The Number Of Test Case Created';
-$lang->block->cmmi = 'CMMI 3';
+$lang->block->waterfall = 'CMMI 3';
$lang->block->scrum = 'Scrum+';
$lang->block->allProject = 'All ' . $lang->projectCommon;
$lang->block->doingProject = 'Doning ' . $lang->projectCommon;
@@ -86,47 +86,47 @@ $lang->block->totalStory = 'The Total ' . $lang->storyCommon;
$lang->block->totalBug = 'The Total Bug';
$lang->block->totalRelease = 'Release The Number';
-$lang->block->default['cmmi']['program']['1']['title'] = $lang->projectCommon . 'Weekly';
-$lang->block->default['cmmi']['program']['1']['block'] = 'Pmmireport';
-$lang->block->default['cmmi']['program']['1']['source'] = 'Program';
-$lang->block->default['cmmi']['program']['1']['grid'] = 8;
+$lang->block->default['waterfall']['program']['1']['title'] = $lang->projectCommon . 'Weekly';
+$lang->block->default['waterfall']['program']['1']['block'] = 'Pmmireport';
+$lang->block->default['waterfall']['program']['1']['source'] = 'Program';
+$lang->block->default['waterfall']['program']['1']['grid'] = 8;
-$lang->block->default['cmmi']['program']['2']['title'] = 'Estimate';
-$lang->block->default['cmmi']['program']['2']['block'] = 'cmmiestimate';
-$lang->block->default['cmmi']['program']['2']['source'] = 'program';
-$lang->block->default['cmmi']['program']['2']['grid'] = 4;
+$lang->block->default['waterfall']['program']['2']['title'] = 'Estimate';
+$lang->block->default['waterfall']['program']['2']['block'] = 'waterfallestimate';
+$lang->block->default['waterfall']['program']['2']['source'] = 'program';
+$lang->block->default['waterfall']['program']['2']['grid'] = 4;
-$lang->block->default['cmmi']['program']['3']['title'] = 'Plan Gantt Chart';
-$lang->block->default['cmmi']['program']['3']['block'] = 'cmmigantt';
-$lang->block->default['cmmi']['program']['3']['source'] = 'program';
-$lang->block->default['cmmi']['program']['3']['grid'] = 8;
+$lang->block->default['waterfall']['program']['3']['title'] = 'Plan Gantt Chart';
+$lang->block->default['waterfall']['program']['3']['block'] = 'waterfallgantt';
+$lang->block->default['waterfall']['program']['3']['source'] = 'program';
+$lang->block->default['waterfall']['program']['3']['grid'] = 8;
-$lang->block->default['cmmi']['program']['4']['title'] = 'Progress Chart';
-$lang->block->default['cmmi']['program']['4']['block'] = 'cmmiprogress';
-$lang->block->default['cmmi']['program']['4']['grid'] = 4;
+$lang->block->default['waterfall']['program']['4']['title'] = 'Progress Chart';
+$lang->block->default['waterfall']['program']['4']['block'] = 'waterfallprogress';
+$lang->block->default['waterfall']['program']['4']['grid'] = 4;
-$lang->block->default['cmmi']['program']['5']['title'] = 'Program Issue';
-$lang->block->default['cmmi']['program']['5']['block'] = 'cmmiissue';
-$lang->block->default['cmmi']['program']['5']['source'] = 'program';
-$lang->block->default['cmmi']['program']['5']['grid'] = 8;
+$lang->block->default['waterfall']['program']['5']['title'] = 'Program Issue';
+$lang->block->default['waterfall']['program']['5']['block'] = 'waterfallissue';
+$lang->block->default['waterfall']['program']['5']['source'] = 'program';
+$lang->block->default['waterfall']['program']['5']['grid'] = 8;
-$lang->block->default['cmmi']['program']['5']['params']['type'] = 'all';
-$lang->block->default['cmmi']['program']['5']['params']['num'] = '15';
-$lang->block->default['cmmi']['program']['5']['params']['orderBy'] = 'id_desc';
+$lang->block->default['waterfall']['program']['5']['params']['type'] = 'all';
+$lang->block->default['waterfall']['program']['5']['params']['num'] = '15';
+$lang->block->default['waterfall']['program']['5']['params']['orderBy'] = 'id_desc';
-$lang->block->default['cmmi']['program']['6']['title'] = 'Dynamic';
-$lang->block->default['cmmi']['program']['6']['block'] = 'dynamic';
-$lang->block->default['cmmi']['program']['6']['grid'] = 4;
-$lang->block->default['cmmi']['program']['6']['source'] = '';
+$lang->block->default['waterfall']['program']['6']['title'] = 'Dynamic';
+$lang->block->default['waterfall']['program']['6']['block'] = 'dynamic';
+$lang->block->default['waterfall']['program']['6']['grid'] = 4;
+$lang->block->default['waterfall']['program']['6']['source'] = '';
-$lang->block->default['cmmi']['program']['7']['title'] = $lang->projectCommon . 'Risk';
-$lang->block->default['cmmi']['program']['7']['block'] = 'cmmirisk';
-$lang->block->default['cmmi']['program']['7']['source'] = 'program';
-$lang->block->default['cmmi']['program']['7']['grid'] = 8;
+$lang->block->default['waterfall']['program']['7']['title'] = $lang->projectCommon . 'Risk';
+$lang->block->default['waterfall']['program']['7']['block'] = 'waterfallrisk';
+$lang->block->default['waterfall']['program']['7']['source'] = 'program';
+$lang->block->default['waterfall']['program']['7']['grid'] = 8;
-$lang->block->default['cmmi']['program']['7']['params']['type'] = 'all';
-$lang->block->default['cmmi']['program']['7']['params']['num'] = '15';
-$lang->block->default['cmmi']['program']['7']['params']['orderBy'] = 'id_desc';
+$lang->block->default['waterfall']['program']['7']['params']['type'] = 'all';
+$lang->block->default['waterfall']['program']['7']['params']['num'] = '15';
+$lang->block->default['waterfall']['program']['7']['params']['orderBy'] = 'id_desc';
$lang->block->default['scrum']['program']['1']['title'] = $lang->projectCommon . ' Overall';
$lang->block->default['scrum']['program']['1']['block'] = 'scrumoverall';
@@ -339,14 +339,14 @@ $lang->block->modules['scrum']['index']->availableBlocks->scrumproduct = $lang-
$lang->block->modules['scrum']['index']->availableBlocks->scrumtest = 'Test Version';
$lang->block->modules['scrum']['index']->availableBlocks->scrumroadmap = $lang->productCommon . ' Rode Map';
-$lang->block->modules['cmmi']['index'] = new stdclass();
-$lang->block->modules['cmmi']['index']->availableBlocks = new stdclass();
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmireport = $lang->projectCommon . ' Weekly';
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmiestimate = 'Estimate';
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmigantt = 'Plan Gantt Chart';
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmiprogress = 'Progress Chart';
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmiissue = $lang->projectCommon . ' Issue';
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmirisk = $lang->projectCommon . ' Risk';
+$lang->block->modules['waterfall']['index'] = new stdclass();
+$lang->block->modules['waterfall']['index']->availableBlocks = new stdclass();
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallreport = $lang->projectCommon . ' Weekly';
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallestimate = 'Estimate';
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallgantt = 'Plan Gantt Chart';
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallprogress = 'Progress Chart';
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallissue = $lang->projectCommon . ' Issue';
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallrisk = $lang->projectCommon . ' Risk';
$lang->block->modules['product'] = new stdclass();
$lang->block->modules['product']->availableBlocks = new stdclass();
@@ -472,19 +472,19 @@ $lang->block->typeList->testtask['done'] = 'Done';
$lang->block->typeList->testtask['all'] = 'All';
$lang->block->modules['program']->moreLinkList = new stdclass();
-$lang->block->modules['program']->moreLinkList->recentprogram = 'program|browse|';
-$lang->block->modules['program']->moreLinkList->statistic = 'program|browse|';
-$lang->block->modules['program']->moreLinkList->program = 'program|browse|';
-$lang->block->modules['program']->moreLinkList->cmmireport = 'weekly|index|';
-$lang->block->modules['program']->moreLinkList->cmmiestimate = 'workestimation|index|';
-$lang->block->modules['program']->moreLinkList->cmmiissue = 'issue|browse|';
-$lang->block->modules['program']->moreLinkList->cmmirisk = 'risk|browse|';
-$lang->block->modules['program']->moreLinkList->scrumlist = 'project|all|';
-$lang->block->modules['program']->moreLinkList->scrumroadmap = 'product|all|';
-$lang->block->modules['program']->moreLinkList->scrumtest = 'testtask|browse|';
-$lang->block->modules['program']->moreLinkList->scrumproduct = 'product|all|';
-$lang->block->modules['program']->moreLinkList->scrumproject = 'project|all|';
-$lang->block->modules['program']->moreLinkList->scrumdynamic = 'company|dynamic|';
+$lang->block->modules['program']->moreLinkList->recentprogram = 'program|browse|';
+$lang->block->modules['program']->moreLinkList->statistic = 'program|browse|';
+$lang->block->modules['program']->moreLinkList->program = 'program|browse|';
+$lang->block->modules['program']->moreLinkList->waterfallreport = 'weekly|index|';
+$lang->block->modules['program']->moreLinkList->waterfallestimate = 'workestimation|index|';
+$lang->block->modules['program']->moreLinkList->waterfallissue = 'issue|browse|';
+$lang->block->modules['program']->moreLinkList->waterfallrisk = 'risk|browse|';
+$lang->block->modules['program']->moreLinkList->scrumlist = 'project|all|';
+$lang->block->modules['program']->moreLinkList->scrumroadmap = 'product|all|';
+$lang->block->modules['program']->moreLinkList->scrumtest = 'testtask|browse|';
+$lang->block->modules['program']->moreLinkList->scrumproduct = 'product|all|';
+$lang->block->modules['program']->moreLinkList->scrumproject = 'project|all|';
+$lang->block->modules['program']->moreLinkList->scrumdynamic = 'company|dynamic|';
$lang->block->modules['product']->moreLinkList = new stdclass();
$lang->block->modules['product']->moreLinkList->list = 'product|all|product=&line=0&status=%s';
diff --git a/module/block/lang/fr.php b/module/block/lang/fr.php
index 55e1be6419..15874d1373 100644
--- a/module/block/lang/fr.php
+++ b/module/block/lang/fr.php
@@ -50,7 +50,7 @@ $lang->block->openedStories = 'The Number Of Stories Created';
$lang->block->resolvedTasks = 'The Number Of Tasks Resolved';
$lang->block->resolvedBugs = 'The Number Of Bugs Resolved';
$lang->block->openedTestcases = 'The Number Of Test Case Created';
-$lang->block->cmmi = 'CMMI 3';
+$lang->block->waterfall = 'CMMI 3';
$lang->block->scrum = 'Scrum+';
$lang->block->params = new stdclass();
diff --git a/module/block/lang/vi.php b/module/block/lang/vi.php
index 0de9be0cc8..bafc617cbe 100644
--- a/module/block/lang/vi.php
+++ b/module/block/lang/vi.php
@@ -50,7 +50,7 @@ $lang->block->openedStories = 'The Number Of Stories Created';
$lang->block->resolvedTasks = 'The Number Of Tasks Resolved';
$lang->block->resolvedBugs = 'The Number Of Bugs Resolved';
$lang->block->openedTestcases = 'The Number Of Test Case Created';
-$lang->block->cmmi = 'CMMI 3';
+$lang->block->waterfall = 'CMMI 3';
$lang->block->scrum = 'Scrum+';
$lang->block->params = new stdclass();
diff --git a/module/block/lang/zh-cn.php b/module/block/lang/zh-cn.php
index 75ea891da2..1c7b445fda 100644
--- a/module/block/lang/zh-cn.php
+++ b/module/block/lang/zh-cn.php
@@ -52,7 +52,7 @@ $lang->block->openedStories = '创建的需求数';
$lang->block->resolvedTasks = '完成的任务数';
$lang->block->resolvedBugs = '解决Bug数';
$lang->block->openedTestcases = '创建用例数';
-$lang->block->cmmi = 'CMMI 3';
+$lang->block->waterfall = 'CMMI 3';
$lang->block->scrum = 'Scrum+';
$lang->block->allProject = '所有' . $lang->projectCommon;
$lang->block->doingProject = '进行中的' . $lang->projectCommon;
@@ -62,6 +62,7 @@ $lang->block->consumedHours = '已消耗';
$lang->block->time = '第';
$lang->block->week = '周';
$lang->block->month = '月';
+$lang->block->selectProduct = '选择产品';
$lang->block->params = new stdclass();
$lang->block->params->name = '参数名称';
@@ -92,48 +93,47 @@ $lang->block->spent = '已花费';
$lang->block->budget = '预算';
$lang->block->left = '剩余';
+$lang->block->default['waterfall']['program']['1']['title'] = '项目周报';
+$lang->block->default['waterfall']['program']['1']['block'] = 'waterfallreport';
+$lang->block->default['waterfall']['program']['1']['source'] = 'program';
+$lang->block->default['waterfall']['program']['1']['grid'] = 8;
-$lang->block->default['cmmi']['program']['1']['title'] = '项目周报';
-$lang->block->default['cmmi']['program']['1']['block'] = 'cmmireport';
-$lang->block->default['cmmi']['program']['1']['source'] = 'program';
-$lang->block->default['cmmi']['program']['1']['grid'] = 8;
+$lang->block->default['waterfall']['program']['2']['title'] = '估算';
+$lang->block->default['waterfall']['program']['2']['block'] = 'waterfallestimate';
+$lang->block->default['waterfall']['program']['2']['source'] = 'program';
+$lang->block->default['waterfall']['program']['2']['grid'] = 4;
-$lang->block->default['cmmi']['program']['2']['title'] = '估算';
-$lang->block->default['cmmi']['program']['2']['block'] = 'cmmiestimate';
-$lang->block->default['cmmi']['program']['2']['source'] = 'program';
-$lang->block->default['cmmi']['program']['2']['grid'] = 4;
+$lang->block->default['waterfall']['program']['3']['title'] = '项目计划';
+$lang->block->default['waterfall']['program']['3']['block'] = 'waterfallgantt';
+$lang->block->default['waterfall']['program']['3']['source'] = 'program';
+$lang->block->default['waterfall']['program']['3']['grid'] = 8;
-$lang->block->default['cmmi']['program']['3']['title'] = '计划甘特图';
-$lang->block->default['cmmi']['program']['3']['block'] = 'cmmigantt';
-$lang->block->default['cmmi']['program']['3']['source'] = 'program';
-$lang->block->default['cmmi']['program']['3']['grid'] = 8;
+$lang->block->default['waterfall']['program']['4']['title'] = '到目前为止项目进展趋势图';
+$lang->block->default['waterfall']['program']['4']['block'] = 'waterfallprogress';
+$lang->block->default['waterfall']['program']['4']['grid'] = 4;
-$lang->block->default['cmmi']['program']['4']['title'] = '到目前为止项目进展趋势图';
-$lang->block->default['cmmi']['program']['4']['block'] = 'cmmiprogress';
-$lang->block->default['cmmi']['program']['4']['grid'] = 4;
+$lang->block->default['waterfall']['program']['5']['title'] = '项目问题';
+$lang->block->default['waterfall']['program']['5']['block'] = 'waterfallissue';
+$lang->block->default['waterfall']['program']['5']['source'] = 'program';
+$lang->block->default['waterfall']['program']['5']['grid'] = 8;
-$lang->block->default['cmmi']['program']['5']['title'] = '项目问题';
-$lang->block->default['cmmi']['program']['5']['block'] = 'cmmiissue';
-$lang->block->default['cmmi']['program']['5']['source'] = 'program';
-$lang->block->default['cmmi']['program']['5']['grid'] = 8;
+$lang->block->default['waterfall']['program']['5']['params']['type'] = 'all';
+$lang->block->default['waterfall']['program']['5']['params']['num'] = '15';
+$lang->block->default['waterfall']['program']['5']['params']['orderBy'] = 'id_desc';
-$lang->block->default['cmmi']['program']['5']['params']['type'] = 'all';
-$lang->block->default['cmmi']['program']['5']['params']['num'] = '15';
-$lang->block->default['cmmi']['program']['5']['params']['orderBy'] = 'id_desc';
+$lang->block->default['waterfall']['program']['6']['title'] = '最新动态';
+$lang->block->default['waterfall']['program']['6']['block'] = 'scrumdynamic';
+$lang->block->default['waterfall']['program']['6']['grid'] = 4;
+$lang->block->default['waterfall']['program']['6']['source'] = 'program';
-$lang->block->default['cmmi']['program']['6']['title'] = '最新动态';
-$lang->block->default['cmmi']['program']['6']['block'] = 'scrumdynamic';
-$lang->block->default['cmmi']['program']['6']['grid'] = 4;
-$lang->block->default['cmmi']['program']['6']['source'] = 'program';
+$lang->block->default['waterfall']['program']['7']['title'] = '项目风险';
+$lang->block->default['waterfall']['program']['7']['block'] = 'waterfallrisk';
+$lang->block->default['waterfall']['program']['7']['source'] = 'program';
+$lang->block->default['waterfall']['program']['7']['grid'] = 8;
-$lang->block->default['cmmi']['program']['7']['title'] = '项目风险';
-$lang->block->default['cmmi']['program']['7']['block'] = 'cmmirisk';
-$lang->block->default['cmmi']['program']['7']['source'] = 'program';
-$lang->block->default['cmmi']['program']['7']['grid'] = 8;
-
-$lang->block->default['cmmi']['program']['7']['params']['type'] = 'all';
-$lang->block->default['cmmi']['program']['7']['params']['num'] = '15';
-$lang->block->default['cmmi']['program']['7']['params']['orderBy'] = 'id_desc';
+$lang->block->default['waterfall']['program']['7']['params']['type'] = 'all';
+$lang->block->default['waterfall']['program']['7']['params']['num'] = '15';
+$lang->block->default['waterfall']['program']['7']['params']['orderBy'] = 'id_desc';
$lang->block->default['scrum']['program']['1']['title'] = '项目整体情况';
$lang->block->default['scrum']['program']['1']['block'] = 'scrumoverall';
@@ -346,14 +346,14 @@ $lang->block->modules['scrum']['index']->availableBlocks->scrumproject = $lang-
$lang->block->modules['scrum']['index']->availableBlocks->scrumproduct = $lang->productCommon . '总览';
$lang->block->modules['scrum']['index']->availableBlocks->scrumtest = '待测版本';
-$lang->block->modules['cmmi']['index'] = new stdclass();
-$lang->block->modules['cmmi']['index']->availableBlocks = new stdclass();
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmireport = '项目周报';
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmiestimate = '估算';
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmigantt = '计划甘特图';
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmiprogress = '到目前为止项目进展趋势图';
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmiissue = '项目问题';
-$lang->block->modules['cmmi']['index']->availableBlocks->cmmirisk = '项目风险';
+$lang->block->modules['waterfall']['index'] = new stdclass();
+$lang->block->modules['waterfall']['index']->availableBlocks = new stdclass();
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallreport = '项目周报';
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallestimate = '估算';
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallgantt = '计划甘特图';
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallprogress = '到目前为止项目进展趋势图';
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallissue = '项目问题';
+$lang->block->modules['waterfall']['index']->availableBlocks->waterfallrisk = '项目风险';
$lang->block->modules['product'] = new stdclass();
$lang->block->modules['product']->availableBlocks = new stdclass();
@@ -479,18 +479,18 @@ $lang->block->typeList->testtask['done'] = '已测版本';
$lang->block->typeList->testtask['all'] = '全部';
$lang->block->modules['program']->moreLinkList = new stdclass();
-$lang->block->modules['program']->moreLinkList->recentprogram = 'program|browse|';
-$lang->block->modules['program']->moreLinkList->statistic = 'program|browse|';
-$lang->block->modules['program']->moreLinkList->program = 'program|browse|';
-$lang->block->modules['program']->moreLinkList->cmmireport = 'weekly|index|';
-$lang->block->modules['program']->moreLinkList->cmmiestimate = 'workestimation|index|';
-$lang->block->modules['program']->moreLinkList->cmmiissue = 'issue|browse|';
-$lang->block->modules['program']->moreLinkList->cmmirisk = 'risk|browse|';
-$lang->block->modules['program']->moreLinkList->scrumlist = 'project|all|';
-$lang->block->modules['program']->moreLinkList->scrumtest = 'testtask|browse|';
-$lang->block->modules['program']->moreLinkList->scrumproduct = 'product|all|';
-$lang->block->modules['program']->moreLinkList->scrumproject = 'project|all|';
-$lang->block->modules['program']->moreLinkList->scrumdynamic = 'company|dynamic|';
+$lang->block->modules['program']->moreLinkList->recentprogram = 'program|browse|';
+$lang->block->modules['program']->moreLinkList->statistic = 'program|browse|';
+$lang->block->modules['program']->moreLinkList->program = 'program|browse|';
+$lang->block->modules['program']->moreLinkList->waterfallreport = 'weekly|index|';
+$lang->block->modules['program']->moreLinkList->waterfallestimate = 'workestimation|index|';
+$lang->block->modules['program']->moreLinkList->waterfallissue = 'issue|browse|';
+$lang->block->modules['program']->moreLinkList->waterfallrisk = 'risk|browse|';
+$lang->block->modules['program']->moreLinkList->scrumlist = 'project|all|';
+$lang->block->modules['program']->moreLinkList->scrumtest = 'testtask|browse|';
+$lang->block->modules['program']->moreLinkList->scrumproduct = 'product|all|';
+$lang->block->modules['program']->moreLinkList->scrumproject = 'project|all|';
+$lang->block->modules['program']->moreLinkList->scrumdynamic = 'company|dynamic|';
$lang->block->modules['product']->moreLinkList = new stdclass();
$lang->block->modules['product']->moreLinkList->list = 'product|all|product=&line=0&status=%s';
diff --git a/module/block/lang/zh-tw.php b/module/block/lang/zh-tw.php
index 8564e7dd91..6e5247d8fd 100644
--- a/module/block/lang/zh-tw.php
+++ b/module/block/lang/zh-tw.php
@@ -50,7 +50,7 @@ $lang->block->openedStories = '創建的需求數';
$lang->block->resolvedTasks = '完成的任務數';
$lang->block->resolvedBugs = '解決Bug數';
$lang->block->openedTestcases = '創建用例數';
-$lang->block->cmmi = 'CMMI 3';
+$lang->block->waterfall = 'CMMI 3';
$lang->block->scrum = 'Scrum+';
$lang->block->params = new stdclass();
diff --git a/module/block/view/productstatisticblock.html.php b/module/block/view/productstatisticblock.html.php
index 3a8cddc586..5c0943338d 100644
--- a/module/block/view/productstatisticblock.html.php
+++ b/module/block/view/productstatisticblock.html.php
@@ -191,7 +191,7 @@ $(function()
- " . $lang->project->create, '', "class='btn btn-info' data-toggle='modal' data-type='ajax'");?>
+ " . $lang->project->create, '', "class='btn btn-info'");?>
diff --git a/module/block/view/projectblock.html.php b/module/block/view/projectblock.html.php
index 639a763302..15da1f159d 100644
--- a/module/block/view/projectblock.html.php
+++ b/module/block/view/projectblock.html.php
@@ -11,7 +11,7 @@
*/
?>
-
diff --git a/module/block/view/recentprogramblock.html.php b/module/block/view/recentprogramblock.html.php
index 50c64f19ed..372b4c94cb 100644
--- a/module/block/view/recentprogramblock.html.php
+++ b/module/block/view/recentprogramblock.html.php
@@ -37,8 +37,8 @@
" . $lang->project->create, '', "class='btn btn-primary' data-toggle='modal' data-type='ajax'")?>
+ " . $lang->project->create, '', "class='btn btn-primary'")?>
| durationestimation->people;?> | diff --git a/module/block/view/cmmiganttblock.html.php b/module/block/view/waterfallganttblock.html.php similarity index 84% rename from module/block/view/cmmiganttblock.html.php rename to module/block/view/waterfallganttblock.html.php index e8095fd715..bbb9570ac4 100644 --- a/module/block/view/cmmiganttblock.html.php +++ b/module/block/view/waterfallganttblock.html.php @@ -1,7 +1,8 @@design->createdBy);?> | design->createdDate);?> | design->assignedTo);?> | -design->actions;?> | +design->actions;?> | ||||||||||||||||||||||||||||||||||||||||||||||||||||||||
|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|
| id);?> | -design->typeList, $design->type);?> | -createLink('design', 'view', "id={$design->id}"), $design->name);?> | -commit;?> | -createdBy;?> | -createdDate, 0, 11);?> | -design->printAssignedHtml($design, $users);?> | +id);?> | +design->typeList, $design->type);?> | +createLink('design', 'view', "id={$design->id}"), $design->name);?> | +commit;?> | +createdBy;?> | +createdDate, 0, 11);?> | +design->printAssignedHtml($design, $users);?> |
id}";
diff --git a/module/design/view/create.html.php b/module/design/view/create.html.php
index a82134215e..54bec96108 100644
--- a/module/design/view/create.html.php
+++ b/module/design/view/create.html.php
@@ -2,7 +2,7 @@
/**
* The create view of design module of ZenTaoPMS.
*
- * @copyright Copyright 2009-2015 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
+ * @copyright Copyright 2009-2020 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
* @license ZPL (http://zpl.pub/page/zplv12.html)
* @author Chunsheng Wang
|
diff --git a/module/block/control.php b/module/block/control.php
index 20a9c21acd..6e3120bd6f 100644
--- a/module/block/control.php
+++ b/module/block/control.php
@@ -206,16 +206,14 @@ class block extends control
{
if($this->loadModel('user')->isLogon()) $this->session->set('blockModule', $module);
$blocks = $this->block->getBlockList($module, $type);
+
+ $common = 'common';
if($module == 'program')
{
- $program = $this->loadModel('project')->getByID($this->app->session->program);
+ $program = $this->loadModel('project')->getByID($this->session->program);
$common = $program->template . 'common';
- $inited = empty($this->config->$module->$common->blockInited) ? '' : $this->config->$module->$common->blockInited;
- }
- else
- {
- $inited = empty($this->config->$module->common->blockInited) ? '' : $this->config->$module->common->blockInited;
}
+ $inited = empty($this->config->$module->$common->blockInited) ? '' : $this->config->$module->$common->blockInited;
/* Init block when vist index first. */
if((empty($blocks) and !$inited and !defined('TUTORIAL')))
@@ -725,6 +723,7 @@ class block extends control
public function printProgramBlock()
{
$this->app->loadLang('project');
+ $this->app->loadLang('task');
$this->view->programs = $this->loadModel('program')->getProgramOverview('byStatus', 'all', $this->params->orderBy, $this->params->num);
$this->view->users = $this->loadModel('user')->getPairs('noletter');
@@ -818,7 +817,7 @@ class block extends control
$program->progress = $program->allStories == 0 ? 0 : round($program->doneStories / $program->allStories, 3) * 100;
$program->projects = $this->project->getProjectStats('all', 0, 0, 1, 'id_desc', null, $programID);
}
- elseif($program->template == 'cmmi')
+ elseif($program->template == 'waterfall')
{
$begin = $program->begin;
$weeks = $this->weekly->getWeekPairs($begin);
@@ -1102,12 +1101,12 @@ class block extends control
}
/**
* Print cmmi report block.
*
* @access public
* @return void
*/
- public function printCmmiReportBlock()
+ public function printWaterfallReportBlock()
{
$this->loadModel('program');
$program = $this->loadModel('project')->getByID($this->session->program);
@@ -1135,12 +1134,12 @@ class block extends control
}
/**
* Print cmmi gantt block.
*
* @access public
* @return void
*/
- public function printCmmiGanttBlock()
+ public function printWaterfallGanttBlock()
{
$products = $this->loadModel('product')->getPairs('', $this->session->program);
$productID = isset($this->session->product) ? 0 : $this->session->product;
@@ -1152,12 +1151,12 @@ class block extends control
}
/**
* Print cmmi issue block.
*
* @access public
* @return void
*/
- public function printCmmiIssueBlock()
+ public function printWaterfallIssueBlock()
{
$uri = $this->app->getURI(true);
$this->session->set('issueList', $uri);
@@ -1167,12 +1166,12 @@ class block extends control
}
/**
* Print cmmi risk block.
*
* @access public
* @return void
*/
- public function printCmmiRiskBlock()
+ public function printWaterfallRiskBlock()
{
$uri = $this->app->getURI(true);
$this->session->set('riskList', $uri);
@@ -1181,12 +1180,12 @@ class block extends control
}
/**
* Print cmmi estimate block.
*
* @access public
* @return void
*/
- public function printCmmiEstimateBlock()
+ public function printWaterfallEstimateBlock()
{
$this->app->loadLang('durationestimation');
$programID = $this->session->program;
@@ -1201,12 +1200,12 @@ class block extends control
}
/**
* Print cmmi progress block.
*
* @access public
* @return void
*/
- public function printCmmiProgressBlock()
+ public function printWaterfallProgressBlock()
{
$this->loadModel('milestone');
$this->loadModel('weekly');
@@ -1102,12 +1101,12 @@ class block extends control
}
/**
- * Print cmmi report block.
+ * Print waterfall report block.
*
* @access public
@@ -1135,12 +1134,12 @@ class block extends control
}
/**
- * Print cmmi gantt block.
+ * Print waterfall gantt block.
*
* @access public
@@ -1152,12 +1151,12 @@ class block extends control
}
/**
- * Print cmmi issue block.
+ * Print waterfall issue block.
*
* @access public
@@ -1167,12 +1166,12 @@ class block extends control
}
/**
- * Print cmmi risk block.
+ * Print waterfall risk block.
*
* @access public
@@ -1181,12 +1180,12 @@ class block extends control
}
/**
- * Print cmmi estimate block.
+ * Print waterfall estimate block.
*
* @access public
@@ -1201,12 +1200,12 @@ class block extends control
}
/**
- * Print cmmi progress block.
+ * Print waterfall progress block.
*
* @access public
diff --git a/module/block/model.php b/module/block/model.php
index 51167f39f9..e1386f0abd 100644
--- a/module/block/model.php
+++ b/module/block/model.php
@@ -59,7 +59,7 @@ class blockModel extends model
unset($_SESSION['album'][$uid]);
}
- if(strpos($data->block, 'cmmi') !== false) $data->type = 'cmmi';
+ if(strpos($data->block, 'waterfall') !== false) $data->type = 'waterfall';
if(strpos($data->block, 'scrum') !== false) $data->type = 'scrum';
$data->params = helper::jsonEncode($data->params);
$this->dao->replace(TABLE_BLOCK)->data($data)->exec();
@@ -628,12 +628,12 @@ class blockModel extends model
}
/**
* Get cmmi program report pararms.
*
* @access public
* @return string
*/
- public function getCmmireportParams()
+ public function getWaterfallreportParams()
{
return false;
}
@@ -644,7 +644,7 @@ class blockModel extends model
* @access public
* @return string
*/
- public function getCmmiestimateParams()
+ public function getWaterfallestimateParams()
{
return false;
}
@@ -655,7 +655,7 @@ class blockModel extends model
* @access public
* @return string
*/
- public function getCmmiganttParams()
+ public function getWaterfallganttParams()
{
return false;
}
@@ -666,19 +666,19 @@ class blockModel extends model
* @access public
* @return string
*/
- public function getCmmiprogressParams()
+ public function getWaterfallprogressParams()
{
return false;
}
/**
* Get cmmi issue params.
*
* @param string $module
* @access public
* @return void
*/
- public function getCmmiissueParams($module = '')
+ public function getWaterfallissueParams($module = '')
{
$this->app->loadLang('issue');
$params = new stdclass();
@@ -698,13 +698,13 @@ class blockModel extends model
}
/**
* Get cmmi risk params.
*
* @param string $module▫
* @access public
* @return void
*/
- public function getCmmiriskParams($module = '')
+ public function getWaterfallriskParams($module = '')
{
$this->app->loadLang('risk');
$params = new stdclass();
@@ -628,12 +628,12 @@ class blockModel extends model
}
/**
- * Get cmmi program report pararms.
+ * Get waterfall program report pararms.
*
* @access public
@@ -666,19 +666,19 @@ class blockModel extends model
}
/**
- * Get cmmi issue params.
+ * Get waterfall issue params.
*
* @param string $module
@@ -698,13 +698,13 @@ class blockModel extends model
}
/**
- * Get cmmi risk params.
+ * Get waterfall risk params.
*
* @param string $module▫